@@ -304,16 +304,25 @@ show_notification (gpointer user_data)
 }
 
 static gboolean
-reason_is_blacklisted (const gchar *reason) {
+reason_is_blacklisted (const gchar *reason)
+{
         if (g_str_equal (reason, "none"))
                 return TRUE;
+
         if (g_str_equal (reason, "other"))
                 return TRUE;
+
         if (g_str_equal (reason, "com.apple.print.recoverable"))
                 return TRUE;
+
         /* https://bugzilla.redhat.com/show_bug.cgi?id=883401 */
         if (g_str_has_prefix (reason, "cups-remote-"))
                 return TRUE;
+
+        /* https://bugzilla.redhat.com/show_bug.cgi?id=1207154 */
+        if (g_str_equal (reason, "cups-waiting-for-job-completed"))
+                return TRUE;
+
         return FALSE;
 }
 
@@ -329,6 +338,69 @@ on_cups_notification (GDBusConnection *connection,
         process_new_notifications (user_data);
 }
 
+static gchar *
+get_statuses_second (guint i,
+                     const gchar *printer_name)
+{
+        gchar *status;
+
+        switch (i) {
+                case 0:
+                        /* Translators: The printer is low on toner (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” is low on toner."), printer_name);
+                        break;
+                case 1:
+                        /* Translators: The printer has no toner left (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” has no toner left."), printer_name);
+                        break;
+                case 2:
+                        /* Translators: The printer is in the process of connecting to a shared network output device (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” may not be connected."), printer_name);
+                        break;
+                case 3:
+                        /* Translators: One or more covers on the printer are open (same as in system-config-printer) */
+                        status = g_strdup_printf (_("The cover is open on printer “%s”."), printer_name);
+                        break;
+                case 4:
+                        /* Translators: A filter or backend is not installed (same as in system-config-printer) */
+                        status = g_strdup_printf (_("There is a missing print filter for "
+                                                    "printer “%s”."), printer_name);
+                        break;
+                case 5:
+                        /* Translators: One or more doors on the printer are open (same as in system-config-printer) */
+                        status = g_strdup_printf (_("The door is open on printer “%s”."), printer_name);
+                        break;
+                case 6:
+                        /* Translators: "marker" is one color bin of the printer */
+                        status = g_strdup_printf (_("Printer “%s” is low on a marker supply."), printer_name);
+                        break;
+                case 7:
+                        /* Translators: "marker" is one color bin of the printer */
+                        status = g_strdup_printf (_("Printer “%s” is out of a marker supply."), printer_name);
+                        break;
+                case 8:
+                        /* Translators: At least one input tray is low on media (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” is low on paper."), printer_name);
+                        break;
+                case 9:
+                        /* Translators: At least one input tray is empty (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” is out of paper."), printer_name);
+                        break;
+                case 10:
+                        /* Translators: The printer is offline (same as in system-config-printer) */
+                        status = g_strdup_printf (_("Printer “%s” is currently off-line."), printer_name);
+                        break;
+                case 11:
+                        /* Translators: The printer has detected an error (same as in system-config-printer) */
+                        status = g_strdup_printf (_("There is a problem on printer “%s”."), printer_name);
+                        break;
+                default:
+                        g_assert_not_reached ();
+        }
+
+        return status;
+}
+
 static void
 process_cups_notification (GsdPrintNotificationsManager *manager,
                            const char                   *notify_subscribed_event,
@@ -392,33 +464,6 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                 /* Translators: The printer has detected an error (same as in system-config-printer) */
                 N_("Printer error") };
 
-        static const char * statuses_second[] = {
-                /* Translators: The printer is low on toner (same as in system-config-printer) */
-                N_("Printer '%s' is low on toner."),
-                /* Translators: The printer has no toner left (same as in system-config-printer) */
-                N_("Printer '%s' has no toner left."),
-                /* Translators: The printer is in the process of connecting to a shared network output device (same as in system-config-printer) */
-                N_("Printer '%s' may not be connected."),
-                /* Translators: One or more covers on the printer are open (same as in system-config-printer) */
-                N_("The cover is open on printer '%s'."),
-                /* Translators: A filter or backend is not installed (same as in system-config-printer) */
-                N_("There is a missing print filter for "
-                   "printer '%s'."),
-                /* Translators: One or more doors on the printer are open (same as in system-config-printer) */
-                N_("The door is open on printer '%s'."),
-                /* Translators: "marker" is one color bin of the printer */
-                N_("Printer '%s' is low on a marker supply."),
-                /* Translators: "marker" is one color bin of the printer */
-                N_("Printer '%s' is out of a marker supply."),
-                /* Translators: At least one input tray is low on media (same as in system-config-printer) */
-                N_("Printer '%s' is low on paper."),
-                /* Translators: At least one input tray is empty (same as in system-config-printer) */
-                N_("Printer '%s' is out of paper."),
-                /* Translators: The printer is offline (same as in system-config-printer) */
-                N_("Printer '%s' is currently off-line."),
-                /* Translators: The printer has detected an error (same as in system-config-printer) */
-                N_("There is a problem on printer '%s'.") };
-
         if (g_strcmp0 (notify_subscribed_event, "printer-added") != 0 &&
             g_strcmp0 (notify_subscribed_event, "printer-deleted") != 0 &&
             g_strcmp0 (notify_subscribed_event, "printer-state-changed") != 0 &&
@@ -469,14 +514,6 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                         secondary_text = g_strdup (printer_name);
                 }
         } else if (g_strcmp0 (notify_subscribed_event, "printer-deleted") == 0) {
-                if (is_local_dest (printer_name,
-                                   manager->priv->dests,
-                                   manager->priv->num_dests)) {
-                        /* Translators: A printer has been removed */
-                        primary_text = g_strdup (_("Printer removed"));
-                        secondary_text = g_strdup (printer_name);
-                }
-
                 cupsFreeDests (manager->priv->num_dests, manager->priv->dests);
                 manager->priv->num_dests = cupsGetDests (&manager->priv->dests);
         } else if (g_strcmp0 (notify_subscribed_event, "job-completed") == 0 && my_job) {
@@ -492,25 +529,25 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A print job has been stopped */
                                 primary_text = g_strdup (C_("print job state", "Printing stopped"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_CANCELED:
                                 /* Translators: A print job has been canceled */
                                 primary_text = g_strdup (C_("print job state", "Printing canceled"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_ABORTED:
                                 /* Translators: A print job has been aborted */
                                 primary_text = g_strdup (C_("print job state", "Printing aborted"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_COMPLETED:
                                 /* Translators: A print job has been completed */
                                 primary_text = g_strdup (C_("print job state", "Printing completed"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                 }
         } else if (g_strcmp0 (notify_subscribed_event, "job-state-changed") == 0 && my_job) {
@@ -522,7 +559,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A job is printing */
                                 primary_text = g_strdup (C_("print job state", "Printing"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_STOPPED:
                                 g_hash_table_remove (manager->priv->printing_printers,
@@ -530,7 +567,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A print job has been stopped */
                                 primary_text = g_strdup (C_("print job state", "Printing stopped"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_CANCELED:
                                 g_hash_table_remove (manager->priv->printing_printers,
@@ -538,7 +575,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A print job has been canceled */
                                 primary_text = g_strdup (C_("print job state", "Printing canceled"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_ABORTED:
                                 g_hash_table_remove (manager->priv->printing_printers,
@@ -546,7 +583,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A print job has been aborted */
                                 primary_text = g_strdup (C_("print job state", "Printing aborted"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         case IPP_JOB_COMPLETED:
                                 g_hash_table_remove (manager->priv->printing_printers,
@@ -554,7 +591,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                 /* Translators: A print job has been completed */
                                 primary_text = g_strdup (C_("print job state", "Printing completed"));
                                 /* Translators: "print-job xy" on a printer */
-                                secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                                secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                                 break;
                         default:
                                 break;
@@ -567,7 +604,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                         /* Translators: A job is printing */
                         primary_text = g_strdup (C_("print job state", "Printing"));
                         /* Translators: "print-job xy" on a printer */
-                        secondary_text = g_strdup_printf (C_("print job", "\"%s\" on %s"), job_name, printer_name);
+                        secondary_text = g_strdup_printf (C_("print job", "“%s” on %s"), job_name, printer_name);
                 }
         } else if (g_strcmp0 (notify_subscribed_event, "printer-state-changed") == 0) {
                 cups_dest_t  *dest = NULL;
@@ -699,7 +736,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                                         data = g_new0 (TimeoutData, 1);
                                                         data->printer_name = g_strdup (printer_name);
                                                         data->primary_text = g_strdup ( _(statuses_first[j]));
-                                                        data->secondary_text = g_strdup_printf ( _(statuses_second[j]), printer_name);
+                                                        data->secondary_text = get_statuses_second (j, printer_name);
                                                         data->manager = manager;
 
                                                         data->timeout_id = g_timeout_add_seconds (CONNECTING_TIMEOUT, show_notification, data);
@@ -707,7 +744,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                                         manager->priv->timeouts = g_list_append (manager->priv->timeouts, data);
                                                 } else {
                                                         ReasonData *reason_data;
-                                                        gchar *second_row = g_strdup_printf ( _(statuses_second[j]), printer_name);
+                                                        gchar *second_row = get_statuses_second (j, printer_name);
 
                                                         notification = notify_notification_new ( _(statuses_first[j]),
                                                                                                 second_row,
@@ -795,7 +832,7 @@ process_cups_notification (GsdPrintNotificationsManager *manager,
                                                 text = g_strdup (data);
 
                                         /* Translators: "Printer 'MyPrinterName': 'Description of the report/warning/error from a PPD file'." */
-                                        second_row = g_strdup_printf (_("Printer '%s': '%s'."), printer_name, text);
+                                        second_row = g_strdup_printf (_("Printer “%s”: “%s”."), printer_name, text);
                                         g_free (text);
 
 
@@ -1436,6 +1473,8 @@ gsd_print_notifications_manager_class_init (GsdPrintNotificationsManagerClass *k
 
         object_class->finalize = gsd_print_notifications_manager_finalize;
 
+        notify_init ("gnome-settings-daemon");
+
         g_type_class_add_private (klass, sizeof (GsdPrintNotificationsManagerPrivate));
 }
 
